package com.factory.controller.wx;

import com.factory.base.entity.aggregates.PageBean;
import com.factory.base.entity.aggregates.ResponseBean;
import com.factory.base.entity.po.benteler.BentelerPlan;
import com.factory.base.util.res.ResponseBeanBuilder;
import com.factory.wx.entity.req.*;
import com.factory.wx.entity.res.PlanApprovalDetailRes;
import com.factory.wx.entity.res.PlanPassDetailRes;
import com.factory.wx.service.PlanService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

/**
 * 微信小程序端计划
 *
 * @author sMArT
 * @version 1.0
 * @date 2021-07-05 3:06 下午
 */
@Api(tags = "微信小程序端")
@RestController
@RequestMapping("/wx/plans")
@Slf4j
public class PlanController {

    @Autowired
    private PlanService planService;


    @ApiOperation(value = "计划审批列表")
    @PostMapping("/approval/list")
    public ResponseBean<PageBean<BentelerPlan>> approvalList(@RequestBody PlanListReq planListReq) {
        PageBean<BentelerPlan> approvalList = planService.getApprovalListByPage(planListReq);
        return ResponseBeanBuilder.ok(approvalList);
    }

//    public ResponseBean<Map> approval(HttpServletRequest request) {
//        Long userId = (Long) request.getAttribute("LOGIN_USER_ID");//获取用户id
//        List<PlanApprovalRes> approvalList = planService.getApprovalList(userId);
//        Map map = new HashMap<>();
//        map.put("row", approvalList);
//        return ResponseBeanBuilder.ok(map);
//    }

    @ApiOperation(value = "计划审批详情-首件")
    @PostMapping("/approval/detail/initial")
    public ResponseBean<PlanApprovalDetailRes> approvalDetail(@RequestBody PlanInfoReq planInfoReq) {
        // TODO
        return ResponseBeanBuilder.ok();
    }

    @ApiOperation(value = "计划审批详情-防错")
    @PostMapping("/approval/detail/pm")
    public ResponseBean<PlanApprovalDetailRes> approvalDetailPM(@RequestBody PlanInfoReq planInfoReq) {
        PlanApprovalDetailRes planApprovalDetailRes = planService.getApprovalDetail(planInfoReq);
        return ResponseBeanBuilder.ok(planApprovalDetailRes);
    }


    @ApiOperation(value = "计划审批")
    @PostMapping("/approval/operate")
    public ResponseBean approvalOperate(@RequestBody PlanApprovalReq planApprovalReq) {
        return planService.approvalOperate(planApprovalReq);
    }

    @ApiOperation(value = "计划放行列表")
    @PostMapping("/pass/list")
    public ResponseBean<PageBean<BentelerPlan>> pass(@RequestBody PassListReq passListReq) {
        PageBean<BentelerPlan> passList = planService.getPassListByPage(passListReq);
        return ResponseBeanBuilder.ok(passList);
    }

    @ApiOperation(value = "计划放行详情")
    @PostMapping("/pass/detail")
    public ResponseBean<PlanPassDetailRes> passDetail(@RequestBody PlanInfoReq planInfoReq) {
        PlanPassDetailRes planPassDetailRes = planService.getPassDetail(planInfoReq);
        return ResponseBeanBuilder.ok(planPassDetailRes);
    }

    @ApiOperation(value = "计划放行")
    @PostMapping("/pass/operate")
    public ResponseBean passOperate(@RequestBody PlanApprovalTaskReq planApprovalTaskReq) {
        return planService.approvalTaskOperate(planApprovalTaskReq);
    }

    @ApiOperation(value = "计划提醒列表")
    @PostMapping("/reminder/list")
    public ResponseBean<PageBean<BentelerPlan>> reminder(@RequestBody ReminderReq reminderReq) {
        PageBean<BentelerPlan> reminderList = planService.getReminderListByPage(reminderReq);
        return ResponseBeanBuilder.ok(reminderList);
    }

    @ApiOperation(value = "计划提醒详情")
    @PostMapping("/reminder/detail")
    public ResponseBean reminderDetail(@RequestBody ReminderReq reminderReq) {
        return ResponseBeanBuilder.ok();
    }

}
